
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'services/phase_service.proto')
_sym_db = _symbol_database.Default()
from ..models import phase_pb2 as models_dot_phase__pb2
from ..models import event_pb2 as models_dot_event__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cservices/phase_service.proto\x12\x10parrygg.services\x1a\x12models/phase.proto\x1a\x12models/event.proto"]\n\x0fGetPhaseRequest\x12\x0c\n\x02id\x18\x01 \x01(\tH\x00\x12.\n\x07slug_id\x18\x02 \x01(\x0b2\x1b.parrygg.models.PhaseSlugIdH\x00B\x0c\n\nidentifier"8\n\x10GetPhaseResponse\x12$\n\x05phase\x18\x01 \x01(\x0b2\x15.parrygg.models.Phase"\'\n\x19GetPhasePlacementsRequest\x12\n\n\x02id\x18\x01 \x01(\t"K\n\x1aGetPhasePlacementsResponse\x12-\n\nplacements\x18\x01 \x03(\x0b2\x19.parrygg.models.Placement"\x1f\n\x11ResetPhaseRequest\x12\n\n\x02id\x18\x01 \x01(\t"\x14\n\x12ResetPhaseResponse2\xd6\x01\n\x0cPhaseService\x12S\n\x08GetPhase\x12!.parrygg.services.GetPhaseRequest\x1a".parrygg.services.GetPhaseResponse"\x00\x12q\n\x12GetPhasePlacements\x12+.parrygg.services.GetPhasePlacementsRequest\x1a,.parrygg.services.GetPhasePlacementsResponse"\x00B\x1a\n\x16gg.parry.grpc.servicesP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services.phase_service_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x16gg.parry.grpc.servicesP\x01'
    _globals['_GETPHASEREQUEST']._serialized_start = 90
    _globals['_GETPHASEREQUEST']._serialized_end = 183
    _globals['_GETPHASERESPONSE']._serialized_start = 185
    _globals['_GETPHASERESPONSE']._serialized_end = 241
    _globals['_GETPHASEPLACEMENTSREQUEST']._serialized_start = 243
    _globals['_GETPHASEPLACEMENTSREQUEST']._serialized_end = 282
    _globals['_GETPHASEPLACEMENTSRESPONSE']._serialized_start = 284
    _globals['_GETPHASEPLACEMENTSRESPONSE']._serialized_end = 359
    _globals['_RESETPHASEREQUEST']._serialized_start = 361
    _globals['_RESETPHASEREQUEST']._serialized_end = 392
    _globals['_RESETPHASERESPONSE']._serialized_start = 394
    _globals['_RESETPHASERESPONSE']._serialized_end = 414
    _globals['_PHASESERVICE']._serialized_start = 417
    _globals['_PHASESERVICE']._serialized_end = 631




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/pagination.proto')
_sym_db = _symbol_database.Default()
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17models/pagination.proto\x12\x0eparrygg.models\x1a\x1cgoogle/protobuf/struct.proto"O\n\x11PaginationRequest\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\'\n\x06cursor\x18\x02 \x01(\x0b2\x17.google.protobuf.Struct"T\n\x12PaginationResponse\x12,\n\x0bnext_cursor\x18\x01 \x01(\x0b2\x17.google.protobuf.Struct\x12\x10\n\x08has_more\x18\x02 \x01(\x08B\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.pagination_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_PAGINATIONREQUEST']._serialized_start = 73
    _globals['_PAGINATIONREQUEST']._serialized_end = 152
    _globals['_PAGINATIONRESPONSE']._serialized_start = 154
    _globals['_PAGINATIONRESPONSE']._serialized_end = 238




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/progression.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18models/progression.proto\x12\x0eparrygg.models"\xe6\x01\n\x0bProgression\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08match_id\x18\x02 \x01(\t\x12\x17\n\x0ftarget_phase_id\x18\x03 \x01(\t\x12\x0f\n\x07seed_id\x18\x04 \x01(\t\x12\x18\n\x10origin_placement\x18\x05 \x01(\x05\x12\x13\n\x0borigin_seed\x18\x06 \x01(\x05\x12\x14\n\x0cmatch_winner\x18\x07 \x01(\x08\x12\x14\n\x0cwinners_side\x18\x08 \x01(\x08\x12\x19\n\x11origin_bracket_id\x18\t \x01(\t\x12\x19\n\x11target_bracket_id\x18\n \x01(\t"\xa6\x01\n\x18ProgressionGroupSettings\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rmin_placement\x18\x02 \x01(\x05\x12\x17\n\x0fnum_progressing\x18\x03 \x01(\x05\x12\x17\n\x0ftarget_phase_id\x18\x04 \x01(\t\x125\n\x08behavior\x18\x05 \x01(\x0e2#.parrygg.models.ProgressionBehavior"\xfd\x01\n ProgressionGroupSettingsMutation\x12\x1a\n\rmin_placement\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x1c\n\x0fnum_progressing\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1c\n\x0ftarget_phase_id\x18\x03 \x01(\tH\x02\x88\x01\x01\x12:\n\x08behavior\x18\x04 \x01(\x0e2#.parrygg.models.ProgressionBehaviorH\x03\x88\x01\x01B\x10\n\x0e_min_placementB\x12\n\x10_num_progressingB\x12\n\x10_target_phase_idB\x0b\n\t_behavior*\xac\x01\n\x13ProgressionBehavior\x12$\n PROGRESSION_BEHAVIOR_UNSPECIFIED\x10\x00\x12 \n\x1cPROGRESSION_BEHAVIOR_NATURAL\x10\x01\x12&\n"PROGRESSION_BEHAVIOR_FORCE_WINNERS\x10\x02\x12%\n!PROGRESSION_BEHAVIOR_FORCE_LOSERS\x10\x03B\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.progression_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_PROGRESSIONBEHAVIOR']._serialized_start = 703
    _globals['_PROGRESSIONBEHAVIOR']._serialized_end = 875
    _globals['_PROGRESSION']._serialized_start = 45
    _globals['_PROGRESSION']._serialized_end = 275
    _globals['_PROGRESSIONGROUPSETTINGS']._serialized_start = 278
    _globals['_PROGRESSIONGROUPSETTINGS']._serialized_end = 444
    _globals['_PROGRESSIONGROUPSETTINGSMUTATION']._serialized_start = 447
    _globals['_PROGRESSIONGROUPSETTINGSMUTATION']._serialized_end = 700




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/user.proto')
_sym_db = _symbol_database.Default()
from ..models import image_pb2 as models_dot_image__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11models/user.proto\x12\x0eparrygg.models\x1a\x12models/image.proto"\x88\x02\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tgamer_tag\x18\x02 \x01(\t\x12\x12\n\nfirst_name\x18\x03 \x01(\t\x12\x11\n\tlast_name\x18\x04 \x01(\t\x12\x0e\n\x06bio_md\x18\x05 \x01(\t\x12\x10\n\x08pronouns\x18\x06 \x01(\t\x12\x12\n\navatar_url\x18\x07 \x01(\t\x12\x14\n\x0cbanner_color\x18\x08 \x01(\t\x12\x18\n\x10location_country\x18\t \x01(\t\x12\x16\n\x0elocation_state\x18\n \x01(\t\x12\x15\n\rlocation_city\x18\x0b \x01(\t\x12%\n\x06images\x18\x0c \x03(\x0b2\x15.parrygg.models.Image"\xb5\x03\n\x0bMutableUser\x12\x16\n\tgamer_tag\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nfirst_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tlast_name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x13\n\x06bio_md\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08pronouns\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1c\n\x0favatar_image_id\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x19\n\x0cbanner_color\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1d\n\x10location_country\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x1b\n\x0elocation_state\x18\t \x01(\tH\x08\x88\x01\x01\x12\x1a\n\rlocation_city\x18\n \x01(\tH\t\x88\x01\x01B\x0c\n\n_gamer_tagB\r\n\x0b_first_nameB\x0c\n\n_last_nameB\t\n\x07_bio_mdB\x0b\n\t_pronounsB\x12\n\x10_avatar_image_idB\x0f\n\r_banner_colorB\x13\n\x11_location_countryB\x11\n\x0f_location_stateB\x10\n\x0e_location_cityB\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.user_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_USER']._serialized_start = 58
    _globals['_USER']._serialized_end = 322
    _globals['_MUTABLEUSER']._serialized_start = 325
    _globals['_MUTABLEUSER']._serialized_end = 762




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/game.proto')
_sym_db = _symbol_database.Default()
from ..models import image_pb2 as models_dot_image__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11models/game.proto\x12\x0eparrygg.models\x1a\x12models/image.proto\x1a\x1cgoogle/protobuf/struct.proto"\xc0\x01\n\x04Game\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bdescription\x18\x03 \x01(\t\x12%\n\x06images\x18\x04 \x03(\x0b2\x15.parrygg.models.Image\x12\x0c\n\x04slug\x18\x05 \x01(\t\x12-\n\ncharacters\x18\x06 \x03(\x0b2\x19.parrygg.models.Character\x12%\n\x06stages\x18\x07 \x03(\x0b2\x15.parrygg.models.Stage"\x1c\n\x0cGameMutation\x12\x0c\n\x04name\x18\x01 \x01(\t"y\n\x0eCharacterImage\x12\x0b\n\x03url\x18\x01 \x01(\t\x120\n\x04type\x18\x02 \x01(\x0e2".parrygg.models.CharacterImageType\x12(\n\x07variant\x18\x03 \x01(\x0b2\x17.google.protobuf.Struct"t\n\tCharacter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07game_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04slug\x18\x04 \x01(\t\x12.\n\x06images\x18\x05 \x03(\x0b2\x1e.parrygg.models.CharacterImage"q\n\nStageImage\x12\x0b\n\x03url\x18\x01 \x01(\t\x12,\n\x04type\x18\x02 \x01(\x0e2\x1e.parrygg.models.StageImageType\x12(\n\x07variant\x18\x03 \x01(\x0b2\x17.google.protobuf.Struct"l\n\x05Stage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07game_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04slug\x18\x04 \x01(\t\x12*\n\x06images\x18\x05 \x03(\x0b2\x1a.parrygg.models.StageImage*\x82\x01\n\x12CharacterImageType\x12$\n CHARACTER_IMAGE_TYPE_UNSPECIFIED\x10\x00\x12#\n\x1fCHARACTER_IMAGE_TYPE_STOCK_ICON\x10\x01\x12!\n\x1dCHARACTER_IMAGE_TYPE_PORTRAIT\x10\x02*R\n\x0eStageImageType\x12 \n\x1cSTAGE_IMAGE_TYPE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aSTAGE_IMAGE_TYPE_THUMBNAIL\x10\x01B\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.game_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_CHARACTERIMAGETYPE']._serialized_start = 779
    _globals['_CHARACTERIMAGETYPE']._serialized_end = 909
    _globals['_STAGEIMAGETYPE']._serialized_start = 911
    _globals['_STAGEIMAGETYPE']._serialized_end = 993
    _globals['_GAME']._serialized_start = 88
    _globals['_GAME']._serialized_end = 280
    _globals['_GAMEMUTATION']._serialized_start = 282
    _globals['_GAMEMUTATION']._serialized_end = 310
    _globals['_CHARACTERIMAGE']._serialized_start = 312
    _globals['_CHARACTERIMAGE']._serialized_end = 433
    _globals['_CHARACTER']._serialized_start = 435
    _globals['_CHARACTER']._serialized_end = 551
    _globals['_STAGEIMAGE']._serialized_start = 553
    _globals['_STAGEIMAGE']._serialized_end = 666
    _globals['_STAGE']._serialized_start = 668
    _globals['_STAGE']._serialized_end = 776




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/notification.proto')
_sym_db = _symbol_database.Default()
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ..models import request_pb2 as models_dot_request__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19models/notification.proto\x12\x0eparrygg.models\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14models/request.proto"Y\n\x16NotificationPreference\x12.\n\x04type\x18\x01 \x01(\x0e2 .parrygg.models.NotificationType\x12\x0f\n\x07enabled\x18\x02 \x01(\x08"\x89\x01\n\x0cNotification\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04body\x18\x02 \x01(\t\x125\n\x0edelivery_state\x18\x03 \x01(\x0e2\x1d.parrygg.models.DeliveryState\x12(\n\x07request\x18\x04 \x01(\x0b2\x17.parrygg.models.Request"M\n\x14NotificationMutation\x125\n\x0edelivery_state\x18\x01 \x01(\x0e2\x1d.parrygg.models.DeliveryState*\xd5\x01\n\x10NotificationType\x12!\n\x1dNOTIFICATION_TYPE_UNSPECIFIED\x10\x00\x12\x1d\n\x19NOTIFICATION_TYPE_ACCOUNT\x10\x01\x12\x1f\n\x1bNOTIFICATION_TYPE_ORGANIZER\x10\x02\x12\x1e\n\x1aNOTIFICATION_TYPE_ATTENDEE\x10\x03\x12\x1d\n\x19NOTIFICATION_TYPE_ENTRANT\x10\x04\x12\x1f\n\x1bNOTIFICATION_TYPE_SPECTATOR\x10\x05*\xb7\x01\n\rDeliveryState\x12\x1e\n\x1aDELIVERY_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15DELIVERY_STATE_UNSENT\x10\x01\x12\x17\n\x13DELIVERY_STATE_SENT\x10\x02\x12\x1b\n\x17DELIVERY_STATE_RECEIVED\x10\x03\x12\x1c\n\x18DELIVERY_STATE_DISMISSED\x10\x04\x12\x17\n\x13DELIVERY_STATE_SEEN\x10\x05B\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.notification_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_NOTIFICATIONTYPE']._serialized_start = 411
    _globals['_NOTIFICATIONTYPE']._serialized_end = 624
    _globals['_DELIVERYSTATE']._serialized_start = 627
    _globals['_DELIVERYSTATE']._serialized_end = 810
    _globals['_NOTIFICATIONPREFERENCE']._serialized_start = 100
    _globals['_NOTIFICATIONPREFERENCE']._serialized_end = 189
    _globals['_NOTIFICATION']._serialized_start = 192
    _globals['_NOTIFICATION']._serialized_end = 329
    _globals['_NOTIFICATIONMUTATION']._serialized_start = 331
    _globals['_NOTIFICATIONMUTATION']._serialized_end = 408




'Client and server classes corresponding to protobuf-defined services.'
import grpc
import warnings
from ..services import bracket_service_pb2 as services_dot_bracket__service__pb2
GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(((((f'The grpc package installed is at version {GRPC_VERSION},' + f' but the generated code in services/bracket_service_pb2_grpc.py depends on') + f' grpcio>={GRPC_GENERATED_VERSION}.') + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}') + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'))

class BracketServiceStub(object):
    'BracketService provides tournament bracket management operations.\n    Handles bracket lifecycle, match progression, and final results.\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.GetBracket = channel.unary_unary('/parrygg.services.BracketService/GetBracket', request_serializer=services_dot_bracket__service__pb2.GetBracketRequest.SerializeToString, response_deserializer=services_dot_bracket__service__pb2.GetBracketResponse.FromString, _registered_method=True)
        self.GetBracketTimestamp = channel.unary_unary('/parrygg.services.BracketService/GetBracketTimestamp', request_serializer=services_dot_bracket__service__pb2.GetBracketTimestampRequest.SerializeToString, response_deserializer=services_dot_bracket__service__pb2.GetBracketTimestampResponse.FromString, _registered_method=True)
        self.ResetBracket = channel.unary_unary('/parrygg.services.BracketService/ResetBracket', request_serializer=services_dot_bracket__service__pb2.ResetBracketRequest.SerializeToString, response_deserializer=services_dot_bracket__service__pb2.ResetBracketResponse.FromString, _registered_method=True)
        self.GetBracketPlacements = channel.unary_unary('/parrygg.services.BracketService/GetBracketPlacements', request_serializer=services_dot_bracket__service__pb2.GetBracketPlacementsRequest.SerializeToString, response_deserializer=services_dot_bracket__service__pb2.GetBracketPlacementsResponse.FromString, _registered_method=True)
        self.StartBracket = channel.unary_unary('/parrygg.services.BracketService/StartBracket', request_serializer=services_dot_bracket__service__pb2.StartBracketRequest.SerializeToString, response_deserializer=services_dot_bracket__service__pb2.StartBracketResponse.FromString, _registered_method=True)

class BracketServiceServicer(object):
    'BracketService provides tournament bracket management operations.\n    Handles bracket lifecycle, match progression, and final results.\n    '

    def GetBracket(self, request, context):
        'Retrieve a bracket by ID or slug path.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBracketTimestamp(self, request, context):
        'Get the last modification timestamp for a bracket.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetBracket(self, request, context):
        'Reset a bracket to initial state, clearing all matches.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBracketPlacements(self, request, context):
        'Get final standings for a completed bracket.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartBracket(self, request, context):
        'Start bracket competition and create initial matches.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_BracketServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'GetBracket': grpc.unary_unary_rpc_method_handler(servicer.GetBracket, request_deserializer=services_dot_bracket__service__pb2.GetBracketRequest.FromString, response_serializer=services_dot_bracket__service__pb2.GetBracketResponse.SerializeToString), 'GetBracketTimestamp': grpc.unary_unary_rpc_method_handler(servicer.GetBracketTimestamp, request_deserializer=services_dot_bracket__service__pb2.GetBracketTimestampRequest.FromString, response_serializer=services_dot_bracket__service__pb2.GetBracketTimestampResponse.SerializeToString), 'ResetBracket': grpc.unary_unary_rpc_method_handler(servicer.ResetBracket, request_deserializer=services_dot_bracket__service__pb2.ResetBracketRequest.FromString, response_serializer=services_dot_bracket__service__pb2.ResetBracketResponse.SerializeToString), 'GetBracketPlacements': grpc.unary_unary_rpc_method_handler(servicer.GetBracketPlacements, request_deserializer=services_dot_bracket__service__pb2.GetBracketPlacementsRequest.FromString, response_serializer=services_dot_bracket__service__pb2.GetBracketPlacementsResponse.SerializeToString), 'StartBracket': grpc.unary_unary_rpc_method_handler(servicer.StartBracket, request_deserializer=services_dot_bracket__service__pb2.StartBracketRequest.FromString, response_serializer=services_dot_bracket__service__pb2.StartBracketResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('parrygg.services.BracketService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('parrygg.services.BracketService', rpc_method_handlers)

class BracketService(object):
    'BracketService provides tournament bracket management operations.\n    Handles bracket lifecycle, match progression, and final results.\n    '

    @staticmethod
    def GetBracket(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.BracketService/GetBracket', services_dot_bracket__service__pb2.GetBracketRequest.SerializeToString, services_dot_bracket__service__pb2.GetBracketResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetBracketTimestamp(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.BracketService/GetBracketTimestamp', services_dot_bracket__service__pb2.GetBracketTimestampRequest.SerializeToString, services_dot_bracket__service__pb2.GetBracketTimestampResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def ResetBracket(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.BracketService/ResetBracket', services_dot_bracket__service__pb2.ResetBracketRequest.SerializeToString, services_dot_bracket__service__pb2.ResetBracketResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetBracketPlacements(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.BracketService/GetBracketPlacements', services_dot_bracket__service__pb2.GetBracketPlacementsRequest.SerializeToString, services_dot_bracket__service__pb2.GetBracketPlacementsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def StartBracket(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.BracketService/StartBracket', services_dot_bracket__service__pb2.StartBracketRequest.SerializeToString, services_dot_bracket__service__pb2.StartBracketResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)




'Client and server classes corresponding to protobuf-defined services.'
import grpc
import warnings
from ..services import entrant_service_pb2 as services_dot_entrant__service__pb2
GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(((((f'The grpc package installed is at version {GRPC_VERSION},' + f' but the generated code in services/entrant_service_pb2_grpc.py depends on') + f' grpcio>={GRPC_GENERATED_VERSION}.') + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}') + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'))

class EntrantServiceStub(object):
    'Missing associated documentation comment in .proto file.'

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.GetEventEntrant = channel.unary_unary('/parrygg.services.EntrantService/GetEventEntrant', request_serializer=services_dot_entrant__service__pb2.GetEventEntrantRequest.SerializeToString, response_deserializer=services_dot_entrant__service__pb2.GetEventEntrantResponse.FromString, _registered_method=True)
        self.CreateEventEntrant = channel.unary_unary('/parrygg.services.EntrantService/CreateEventEntrant', request_serializer=services_dot_entrant__service__pb2.CreateEventEntrantRequest.SerializeToString, response_deserializer=services_dot_entrant__service__pb2.CreateEventEntrantResponse.FromString, _registered_method=True)
        self.UpdateEventEntrant = channel.unary_unary('/parrygg.services.EntrantService/UpdateEventEntrant', request_serializer=services_dot_entrant__service__pb2.UpdateEventEntrantRequest.SerializeToString, response_deserializer=services_dot_entrant__service__pb2.UpdateEventEntrantResponse.FromString, _registered_method=True)
        self.DeleteEventEntrant = channel.unary_unary('/parrygg.services.EntrantService/DeleteEventEntrant', request_serializer=services_dot_entrant__service__pb2.DeleteEventEntrantRequest.SerializeToString, response_deserializer=services_dot_entrant__service__pb2.DeleteEventEntrantResponse.FromString, _registered_method=True)
        self.RemoveFromEventEntrant = channel.unary_unary('/parrygg.services.EntrantService/RemoveFromEventEntrant', request_serializer=services_dot_entrant__service__pb2.RemoveFromEventEntrantRequest.SerializeToString, response_deserializer=services_dot_entrant__service__pb2.RemoveFromEventEntrantResponse.FromString, _registered_method=True)
        self.DisbandEventEntrant = channel.unary_unary('/parrygg.services.EntrantService/DisbandEventEntrant', request_serializer=services_dot_entrant__service__pb2.DisbandEventEntrantRequest.SerializeToString, response_deserializer=services_dot_entrant__service__pb2.DisbandEventEntrantResponse.FromString, _registered_method=True)
        self.CreateTeam = channel.unary_unary('/parrygg.services.EntrantService/CreateTeam', request_serializer=services_dot_entrant__service__pb2.CreateTeamRequest.SerializeToString, response_deserializer=services_dot_entrant__service__pb2.CreateTeamResponse.FromString, _registered_method=True)
        self.UpdateTeam = channel.unary_unary('/parrygg.services.EntrantService/UpdateTeam', request_serializer=services_dot_entrant__service__pb2.UpdateTeamRequest.SerializeToString, response_deserializer=services_dot_entrant__service__pb2.UpdateTeamResponse.FromString, _registered_method=True)

class EntrantServiceServicer(object):
    'Missing associated documentation comment in .proto file.'

    def GetEventEntrant(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEventEntrant(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEventEntrant(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEventEntrant(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveFromEventEntrant(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisbandEventEntrant(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTeam(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTeam(self, request, context):
        'Missing associated documentation comment in .proto file.'
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_EntrantServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'GetEventEntrant': grpc.unary_unary_rpc_method_handler(servicer.GetEventEntrant, request_deserializer=services_dot_entrant__service__pb2.GetEventEntrantRequest.FromString, response_serializer=services_dot_entrant__service__pb2.GetEventEntrantResponse.SerializeToString), 'CreateEventEntrant': grpc.unary_unary_rpc_method_handler(servicer.CreateEventEntrant, request_deserializer=services_dot_entrant__service__pb2.CreateEventEntrantRequest.FromString, response_serializer=services_dot_entrant__service__pb2.CreateEventEntrantResponse.SerializeToString), 'UpdateEventEntrant': grpc.unary_unary_rpc_method_handler(servicer.UpdateEventEntrant, request_deserializer=services_dot_entrant__service__pb2.UpdateEventEntrantRequest.FromString, response_serializer=services_dot_entrant__service__pb2.UpdateEventEntrantResponse.SerializeToString), 'DeleteEventEntrant': grpc.unary_unary_rpc_method_handler(servicer.DeleteEventEntrant, request_deserializer=services_dot_entrant__service__pb2.DeleteEventEntrantRequest.FromString, response_serializer=services_dot_entrant__service__pb2.DeleteEventEntrantResponse.SerializeToString), 'RemoveFromEventEntrant': grpc.unary_unary_rpc_method_handler(servicer.RemoveFromEventEntrant, request_deserializer=services_dot_entrant__service__pb2.RemoveFromEventEntrantRequest.FromString, response_serializer=services_dot_entrant__service__pb2.RemoveFromEventEntrantResponse.SerializeToString), 'DisbandEventEntrant': grpc.unary_unary_rpc_method_handler(servicer.DisbandEventEntrant, request_deserializer=services_dot_entrant__service__pb2.DisbandEventEntrantRequest.FromString, response_serializer=services_dot_entrant__service__pb2.DisbandEventEntrantResponse.SerializeToString), 'CreateTeam': grpc.unary_unary_rpc_method_handler(servicer.CreateTeam, request_deserializer=services_dot_entrant__service__pb2.CreateTeamRequest.FromString, response_serializer=services_dot_entrant__service__pb2.CreateTeamResponse.SerializeToString), 'UpdateTeam': grpc.unary_unary_rpc_method_handler(servicer.UpdateTeam, request_deserializer=services_dot_entrant__service__pb2.UpdateTeamRequest.FromString, response_serializer=services_dot_entrant__service__pb2.UpdateTeamResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('parrygg.services.EntrantService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('parrygg.services.EntrantService', rpc_method_handlers)

class EntrantService(object):
    'Missing associated documentation comment in .proto file.'

    @staticmethod
    def GetEventEntrant(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.EntrantService/GetEventEntrant', services_dot_entrant__service__pb2.GetEventEntrantRequest.SerializeToString, services_dot_entrant__service__pb2.GetEventEntrantResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def CreateEventEntrant(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.EntrantService/CreateEventEntrant', services_dot_entrant__service__pb2.CreateEventEntrantRequest.SerializeToString, services_dot_entrant__service__pb2.CreateEventEntrantResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def UpdateEventEntrant(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.EntrantService/UpdateEventEntrant', services_dot_entrant__service__pb2.UpdateEventEntrantRequest.SerializeToString, services_dot_entrant__service__pb2.UpdateEventEntrantResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def DeleteEventEntrant(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.EntrantService/DeleteEventEntrant', services_dot_entrant__service__pb2.DeleteEventEntrantRequest.SerializeToString, services_dot_entrant__service__pb2.DeleteEventEntrantResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def RemoveFromEventEntrant(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.EntrantService/RemoveFromEventEntrant', services_dot_entrant__service__pb2.RemoveFromEventEntrantRequest.SerializeToString, services_dot_entrant__service__pb2.RemoveFromEventEntrantResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def DisbandEventEntrant(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.EntrantService/DisbandEventEntrant', services_dot_entrant__service__pb2.DisbandEventEntrantRequest.SerializeToString, services_dot_entrant__service__pb2.DisbandEventEntrantResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def CreateTeam(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.EntrantService/CreateTeam', services_dot_entrant__service__pb2.CreateTeamRequest.SerializeToString, services_dot_entrant__service__pb2.CreateTeamResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def UpdateTeam(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.EntrantService/UpdateTeam', services_dot_entrant__service__pb2.UpdateTeamRequest.SerializeToString, services_dot_entrant__service__pb2.UpdateTeamResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'services/match_service.proto')
_sym_db = _symbol_database.Default()
from ..models import bracket_pb2 as models_dot_bracket__pb2
from ..models import filter_pb2 as models_dot_filter__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cservices/match_service.proto\x12\x10parrygg.services\x1a\x14models/bracket.proto\x1a\x13models/filter.proto"\x1d\n\x0fGetMatchRequest\x12\n\n\x02id\x18\x01 \x01(\t"8\n\x10GetMatchResponse\x12$\n\x05match\x18\x01 \x01(\x0b2\x15.parrygg.models.Match"B\n\x11GetMatchesRequest\x12-\n\x06filter\x18\x01 \x01(\x0b2\x1d.parrygg.models.MatchesFilter"I\n\x12GetMatchesResponse\x12-\n\x07matches\x18\x02 \x03(\x0b2\x1c.parrygg.models.MatchContextJ\x04\x08\x01\x10\x02"P\n\x15SetMatchResultRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12+\n\x06result\x18\x02 \x01(\x0b2\x1b.parrygg.models.MatchResult"\x18\n\x16SetMatchResultResponse"\x1f\n\x11ResetMatchRequest\x12\n\n\x02id\x18\x01 \x01(\t"\x14\n\x12ResetMatchResponse"\x1f\n\x11StartMatchRequest\x12\n\n\x02id\x18\x01 \x01(\t"\x14\n\x12StartMatchResponse2\xdb\x03\n\x0cMatchService\x12S\n\x08GetMatch\x12!.parrygg.services.GetMatchRequest\x1a".parrygg.services.GetMatchResponse"\x00\x12Y\n\nGetMatches\x12#.parrygg.services.GetMatchesRequest\x1a$.parrygg.services.GetMatchesResponse"\x00\x12e\n\x0eSetMatchResult\x12\'.parrygg.services.SetMatchResultRequest\x1a(.parrygg.services.SetMatchResultResponse"\x00\x12Y\n\nStartMatch\x12#.parrygg.services.StartMatchRequest\x1a$.parrygg.services.StartMatchResponse"\x00\x12Y\n\nResetMatch\x12#.parrygg.services.ResetMatchRequest\x1a$.parrygg.services.ResetMatchResponse"\x00B\x1a\n\x16gg.parry.grpc.servicesP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services.match_service_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x16gg.parry.grpc.servicesP\x01'
    _globals['_GETMATCHREQUEST']._serialized_start = 93
    _globals['_GETMATCHREQUEST']._serialized_end = 122
    _globals['_GETMATCHRESPONSE']._serialized_start = 124
    _globals['_GETMATCHRESPONSE']._serialized_end = 180
    _globals['_GETMATCHESREQUEST']._serialized_start = 182
    _globals['_GETMATCHESREQUEST']._serialized_end = 248
    _globals['_GETMATCHESRESPONSE']._serialized_start = 250
    _globals['_GETMATCHESRESPONSE']._serialized_end = 323
    _globals['_SETMATCHRESULTREQUEST']._serialized_start = 325
    _globals['_SETMATCHRESULTREQUEST']._serialized_end = 405
    _globals['_SETMATCHRESULTRESPONSE']._serialized_start = 407
    _globals['_SETMATCHRESULTRESPONSE']._serialized_end = 431
    _globals['_RESETMATCHREQUEST']._serialized_start = 433
    _globals['_RESETMATCHREQUEST']._serialized_end = 464
    _globals['_RESETMATCHRESPONSE']._serialized_start = 466
    _globals['_RESETMATCHRESPONSE']._serialized_end = 486
    _globals['_STARTMATCHREQUEST']._serialized_start = 488
    _globals['_STARTMATCHREQUEST']._serialized_end = 519
    _globals['_STARTMATCHRESPONSE']._serialized_start = 521
    _globals['_STARTMATCHRESPONSE']._serialized_end = 541
    _globals['_MATCHSERVICE']._serialized_start = 544
    _globals['_MATCHSERVICE']._serialized_end = 1019




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'services/match_game_service.proto')
_sym_db = _symbol_database.Default()
from ..models import bracket_pb2 as models_dot_bracket__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!services/match_game_service.proto\x12\x10parrygg.services\x1a\x14models/bracket.proto"a\n\x16CreateMatchGameRequest\x12\x10\n\x08match_id\x18\x01 \x01(\t\x125\n\nmatch_game\x18\x02 \x01(\x0b2!.parrygg.models.MatchGameMutation"H\n\x17CreateMatchGameResponse\x12-\n\nmatch_game\x18\x01 \x01(\x0b2\x19.parrygg.models.MatchGame"[\n\x16UpdateMatchGameRequest\x12\n\n\x02id\x18\x01 \x01(\t\x125\n\nmatch_game\x18\x02 \x01(\x0b2!.parrygg.models.MatchGameMutation"H\n\x17UpdateMatchGameResponse\x12-\n\nmatch_game\x18\x01 \x01(\x0b2\x19.parrygg.models.MatchGame"$\n\x16DeleteMatchGameRequest\x12\n\n\x02id\x18\x01 \x01(\t"H\n\x17DeleteMatchGameResponse\x12-\n\nmatch_game\x18\x01 \x01(\x0b2\x19.parrygg.models.MatchGame2\xd0\x02\n\x10MatchGameService\x12h\n\x0fCreateMatchGame\x12(.parrygg.services.CreateMatchGameRequest\x1a).parrygg.services.CreateMatchGameResponse"\x00\x12h\n\x0fUpdateMatchGame\x12(.parrygg.services.UpdateMatchGameRequest\x1a).parrygg.services.UpdateMatchGameResponse"\x00\x12h\n\x0fDeleteMatchGame\x12(.parrygg.services.DeleteMatchGameRequest\x1a).parrygg.services.DeleteMatchGameResponse"\x00B\x1a\n\x16gg.parry.grpc.servicesP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services.match_game_service_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x16gg.parry.grpc.servicesP\x01'
    _globals['_CREATEMATCHGAMEREQUEST']._serialized_start = 77
    _globals['_CREATEMATCHGAMEREQUEST']._serialized_end = 174
    _globals['_CREATEMATCHGAMERESPONSE']._serialized_start = 176
    _globals['_CREATEMATCHGAMERESPONSE']._serialized_end = 248
    _globals['_UPDATEMATCHGAMEREQUEST']._serialized_start = 250
    _globals['_UPDATEMATCHGAMEREQUEST']._serialized_end = 341
    _globals['_UPDATEMATCHGAMERESPONSE']._serialized_start = 343
    _globals['_UPDATEMATCHGAMERESPONSE']._serialized_end = 415
    _globals['_DELETEMATCHGAMEREQUEST']._serialized_start = 417
    _globals['_DELETEMATCHGAMEREQUEST']._serialized_end = 453
    _globals['_DELETEMATCHGAMERESPONSE']._serialized_start = 455
    _globals['_DELETEMATCHGAMERESPONSE']._serialized_end = 527
    _globals['_MATCHGAMESERVICE']._serialized_start = 530
    _globals['_MATCHGAMESERVICE']._serialized_end = 866




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/group.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12models/group.proto\x12\x0eparrygg.models"\x07\n\x05Group*m\n\nPermission\x12\x1a\n\x16PERMISSION_UNSPECIFIED\x10\x00\x12\x15\n\x11PERMISSION_MEMBER\x10\x01\x12\x16\n\x12PERMISSION_MANAGER\x10\x02\x12\x14\n\x10PERMISSION_OWNER\x10\x03*V\n\nMemberType\x12\x1b\n\x17MEMBER_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10MEMBER_TYPE_USER\x10\x01\x12\x15\n\x11MEMBER_TYPE_GROUP\x10\x02B\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.group_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_PERMISSION']._serialized_start = 47
    _globals['_PERMISSION']._serialized_end = 156
    _globals['_MEMBERTYPE']._serialized_start = 158
    _globals['_MEMBERTYPE']._serialized_end = 244
    _globals['_GROUP']._serialized_start = 38
    _globals['_GROUP']._serialized_end = 45




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'services/hierarchy_service.proto')
_sym_db = _symbol_database.Default()
from ..models import event_pb2 as models_dot_event__pb2
from ..models import hierarchy_pb2 as models_dot_hierarchy__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n services/hierarchy_service.proto\x12\x10parrygg.services\x1a\x12models/event.proto\x1a\x16models/hierarchy.proto"v\n\x18GetEventHierarchyRequest\x12\x12\n\x08event_id\x18\x01 \x01(\tH\x00\x128\n\x0fevent_slug_path\x18\x02 \x01(\x0b2\x1d.parrygg.models.EventSlugPathH\x00B\x0c\n\nidentifier"I\n\x19GetEventHierarchyResponse\x12,\n\thierarchy\x18\x01 \x01(\x0b2\x19.parrygg.models.Hierarchy"v\n\x18GetPhaseHierarchyRequest\x12\x12\n\x08phase_id\x18\x01 \x01(\tH\x00\x128\n\x0fphase_slug_path\x18\x02 \x01(\x0b2\x1d.parrygg.models.PhaseSlugPathH\x00B\x0c\n\nidentifier"I\n\x19GetPhaseHierarchyResponse\x12,\n\thierarchy\x18\x01 \x01(\x0b2\x19.parrygg.models.Hierarchy"~\n\x1aGetBracketHierarchyRequest\x12\x14\n\nbracket_id\x18\x01 \x01(\tH\x00\x12<\n\x11bracket_slug_path\x18\x02 \x01(\x0b2\x1f.parrygg.models.BracketSlugPathH\x00B\x0c\n\nidentifier"K\n\x1bGetBracketHierarchyResponse\x12,\n\thierarchy\x18\x01 \x01(\x0b2\x19.parrygg.models.Hierarchy"l\n\x1fGetAllBracketHierarchiesRequest\x12;\n\x10event_identifier\x18\x01 \x01(\x0b2\x1f.parrygg.models.EventIdentifierH\x00B\x0c\n\nidentifier"R\n GetAllBracketHierarchiesResponse\x12.\n\x0bhierarchies\x18\x01 \x03(\x0b2\x19.parrygg.models.Hierarchy2\xee\x03\n\x10HierarchyService\x12n\n\x11GetEventHierarchy\x12*.parrygg.services.GetEventHierarchyRequest\x1a+.parrygg.services.GetEventHierarchyResponse"\x00\x12n\n\x11GetPhaseHierarchy\x12*.parrygg.services.GetPhaseHierarchyRequest\x1a+.parrygg.services.GetPhaseHierarchyResponse"\x00\x12t\n\x13GetBracketHierarchy\x12,.parrygg.services.GetBracketHierarchyRequest\x1a-.parrygg.services.GetBracketHierarchyResponse"\x00\x12\x83\x01\n\x18GetAllBracketHierarchies\x121.parrygg.services.GetAllBracketHierarchiesRequest\x1a2.parrygg.services.GetAllBracketHierarchiesResponse"\x00B\x1a\n\x16gg.parry.grpc.servicesP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services.hierarchy_service_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x16gg.parry.grpc.servicesP\x01'
    _globals['_GETEVENTHIERARCHYREQUEST']._serialized_start = 98
    _globals['_GETEVENTHIERARCHYREQUEST']._serialized_end = 216
    _globals['_GETEVENTHIERARCHYRESPONSE']._serialized_start = 218
    _globals['_GETEVENTHIERARCHYRESPONSE']._serialized_end = 291
    _globals['_GETPHASEHIERARCHYREQUEST']._serialized_start = 293
    _globals['_GETPHASEHIERARCHYREQUEST']._serialized_end = 411
    _globals['_GETPHASEHIERARCHYRESPONSE']._serialized_start = 413
    _globals['_GETPHASEHIERARCHYRESPONSE']._serialized_end = 486
    _globals['_GETBRACKETHIERARCHYREQUEST']._serialized_start = 488
    _globals['_GETBRACKETHIERARCHYREQUEST']._serialized_end = 614
    _globals['_GETBRACKETHIERARCHYRESPONSE']._serialized_start = 616
    _globals['_GETBRACKETHIERARCHYRESPONSE']._serialized_end = 691
    _globals['_GETALLBRACKETHIERARCHIESREQUEST']._serialized_start = 693
    _globals['_GETALLBRACKETHIERARCHIESREQUEST']._serialized_end = 801
    _globals['_GETALLBRACKETHIERARCHIESRESPONSE']._serialized_start = 803
    _globals['_GETALLBRACKETHIERARCHIESRESPONSE']._serialized_end = 885
    _globals['_HIERARCHYSERVICE']._serialized_start = 888
    _globals['_HIERARCHYSERVICE']._serialized_end = 1382




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/event.proto')
_sym_db = _symbol_database.Default()
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ..models import entrant_pb2 as models_dot_entrant__pb2
from ..models import game_pb2 as models_dot_game__pb2
from ..models import hierarchy_pb2 as models_dot_hierarchy__pb2
from ..models import phase_pb2 as models_dot_phase__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12models/event.proto\x12\x0eparrygg.models\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14models/entrant.proto\x1a\x11models/game.proto\x1a\x16models/hierarchy.proto\x1a\x12models/phase.proto"\x92\x03\n\x05Event\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rtournament_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x16\n\x0edescription_md\x18\x04 \x01(\t\x12.\n\nstart_date\x18\x05 \x01(\x0b2\x1a.google.protobuf.Timestamp\x12;\n\x17registration_close_time\x18\x06 \x01(\x0b2\x1a.google.protobuf.Timestamp\x12\r\n\x05price\x18\x07 \x01(\x05\x12\x13\n\x0bentrant_cap\x18\x08 \x01(\x05\x12\x14\n\x0centrant_size\x18\t \x01(\x05\x12"\n\x04game\x18\n \x01(\x0b2\x14.parrygg.models.Game\x12%\n\x06phases\x18\x0b \x03(\x0b2\x15.parrygg.models.Phase\x12)\n\x05state\x18\x0c \x01(\x0e2\x1a.parrygg.models.EventState\x12\x0c\n\x04slug\x18\r \x01(\t\x12\x15\n\rentrant_count\x18\x0e \x01(\x05"\x93\x03\n\rEventMutation\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0edescription_md\x18\x02 \x01(\tH\x01\x88\x01\x01\x123\n\nstart_date\x18\x03 \x01(\x0b2\x1a.google.protobuf.TimestampH\x02\x88\x01\x01\x12@\n\x17registration_close_time\x18\x04 \x01(\x0b2\x1a.google.protobuf.TimestampH\x03\x88\x01\x01\x12\x12\n\x05price\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12\x18\n\x0bentrant_cap\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12\x19\n\x0centrant_size\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x14\n\x07game_id\x18\x08 \x01(\tH\x07\x88\x01\x01B\x07\n\x05_nameB\x11\n\x0f_description_mdB\r\n\x0b_start_dateB\x1a\n\x18_registration_close_timeB\x08\n\x06_priceB\x0e\n\x0c_entrant_capB\x0f\n\r_entrant_sizeB\n\n\x08_game_id"\x97\x01\n\x11EventRegistration\x12\x10\n\x08event_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x16\n\x0epaid_event_fee\x18\x03 \x01(\x08\x12\x12\n\nregistered\x18\x04 \x01(\x08\x123\n\revent_entrant\x18\x05 \x01(\x0b2\x1c.parrygg.models.EventEntrant"#\n\x0fEventAttendance\x12\x10\n\x08event_id\x18\x01 \x01(\t"\x85\x01\n\x19EventRegistrationMutation\x12\x10\n\x08event_id\x18\x01 \x01(\t\x12\x1b\n\x0epaid_event_fee\x18\x02 \x01(\x08H\x00\x88\x01\x01\x12\x17\n\nregistered\x18\x03 \x01(\x08H\x01\x88\x01\x01B\x11\n\x0f_paid_event_feeB\r\n\x0b_registered"-\n\x19EventRegistrationDeletion\x12\x10\n\x08event_id\x18\x01 \x01(\t"g\n\x0fEventIdentifier\x12\x0c\n\x02id\x18\x01 \x01(\tH\x00\x128\n\x0fevent_slug_path\x18\x02 \x01(\x0b2\x1d.parrygg.models.EventSlugPathH\x00B\x0c\n\nidentifier"\x7f\n\tPlacement\x123\n\revent_entrant\x18\x01 \x01(\x0b2\x1c.parrygg.models.EventEntrant\x12\x11\n\tplacement\x18\x02 \x01(\x05\x12\x0c\n\x04wins\x18\x03 \x01(\x05\x12\x0e\n\x06losses\x18\x04 \x01(\x05\x12\x0c\n\x04seed\x18\x05 \x01(\x05"v\n\rEntrantResult\x12,\n\tplacement\x18\x01 \x01(\x0b2\x19.parrygg.models.Placement\x12%\n\x06phases\x18\x02 \x03(\x0b2\x15.parrygg.models.Phase\x12\x10\n\x08event_id\x18\x03 \x01(\t*\x91\x01\n\nEventState\x12\x1b\n\x17EVENT_STATE_UNSPECIFIED\x10\x00\x12\x17\n\x13EVENT_STATE_PENDING\x10\x01\x12\x15\n\x11EVENT_STATE_READY\x10\x02\x12\x1b\n\x17EVENT_STATE_IN_PROGRESS\x10\x03\x12\x19\n\x15EVENT_STATE_COMPLETED\x10\x04B\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.event_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_EVENTSTATE']._serialized_start = 1696
    _globals['_EVENTSTATE']._serialized_end = 1841
    _globals['_EVENT']._serialized_start = 157
    _globals['_EVENT']._serialized_end = 559
    _globals['_EVENTMUTATION']._serialized_start = 562
    _globals['_EVENTMUTATION']._serialized_end = 965
    _globals['_EVENTREGISTRATION']._serialized_start = 968
    _globals['_EVENTREGISTRATION']._serialized_end = 1119
    _globals['_EVENTATTENDANCE']._serialized_start = 1121
    _globals['_EVENTATTENDANCE']._serialized_end = 1156
    _globals['_EVENTREGISTRATIONMUTATION']._serialized_start = 1159
    _globals['_EVENTREGISTRATIONMUTATION']._serialized_end = 1292
    _globals['_EVENTREGISTRATIONDELETION']._serialized_start = 1294
    _globals['_EVENTREGISTRATIONDELETION']._serialized_end = 1339
    _globals['_EVENTIDENTIFIER']._serialized_start = 1341
    _globals['_EVENTIDENTIFIER']._serialized_end = 1444
    _globals['_PLACEMENT']._serialized_start = 1446
    _globals['_PLACEMENT']._serialized_end = 1573
    _globals['_ENTRANTRESULT']._serialized_start = 1575
    _globals['_ENTRANTRESULT']._serialized_end = 1693




'Client and server classes corresponding to protobuf-defined services.'
import grpc
import warnings
from ..services import event_service_pb2 as services_dot_event__service__pb2
GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(((((f'The grpc package installed is at version {GRPC_VERSION},' + f' but the generated code in services/event_service_pb2_grpc.py depends on') + f' grpcio>={GRPC_GENERATED_VERSION}.') + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}') + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'))

class EventServiceStub(object):
    'EventService provides tournament event management operations.\n    Handles event lifecycle, registration, and bracket administration.\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.GetEvent = channel.unary_unary('/parrygg.services.EventService/GetEvent', request_serializer=services_dot_event__service__pb2.GetEventRequest.SerializeToString, response_deserializer=services_dot_event__service__pb2.GetEventResponse.FromString, _registered_method=True)
        self.GetEvents = channel.unary_unary('/parrygg.services.EventService/GetEvents', request_serializer=services_dot_event__service__pb2.GetEventsRequest.SerializeToString, response_deserializer=services_dot_event__service__pb2.GetEventsResponse.FromString, _registered_method=True)
        self.GetEventPlacements = channel.unary_unary('/parrygg.services.EventService/GetEventPlacements', request_serializer=services_dot_event__service__pb2.GetEventPlacementsRequest.SerializeToString, response_deserializer=services_dot_event__service__pb2.GetEventPlacementsResponse.FromString, _registered_method=True)
        self.GetEventEntrants = channel.unary_unary('/parrygg.services.EventService/GetEventEntrants', request_serializer=services_dot_event__service__pb2.GetEventEntrantsRequest.SerializeToString, response_deserializer=services_dot_event__service__pb2.GetEventEntrantsResponse.FromString, _registered_method=True)
        self.ResetEvent = channel.unary_unary('/parrygg.services.EventService/ResetEvent', request_serializer=services_dot_event__service__pb2.ResetEventRequest.SerializeToString, response_deserializer=services_dot_event__service__pb2.ResetEventResponse.FromString, _registered_method=True)
        self.GetEntrantResult = channel.unary_unary('/parrygg.services.EventService/GetEntrantResult', request_serializer=services_dot_event__service__pb2.GetEntrantResultRequest.SerializeToString, response_deserializer=services_dot_event__service__pb2.GetEntrantResultResponse.FromString, _registered_method=True)

class EventServiceServicer(object):
    'EventService provides tournament event management operations.\n    Handles event lifecycle, registration, and bracket administration.\n    '

    def GetEvent(self, request, context):
        'Retrieve a single event by ID.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEvents(self, request, context):
        'List events matching filter criteria.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEventPlacements(self, request, context):
        'Get final standings for a completed event.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEventEntrants(self, request, context):
        'List all participants in an event.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetEvent(self, request, context):
        'Reset event brackets and matches to initial state.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEntrantResult(self, request, context):
        "Get detailed results information on a single entrant's performance within an event.\n        "
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_EventServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'GetEvent': grpc.unary_unary_rpc_method_handler(servicer.GetEvent, request_deserializer=services_dot_event__service__pb2.GetEventRequest.FromString, response_serializer=services_dot_event__service__pb2.GetEventResponse.SerializeToString), 'GetEvents': grpc.unary_unary_rpc_method_handler(servicer.GetEvents, request_deserializer=services_dot_event__service__pb2.GetEventsRequest.FromString, response_serializer=services_dot_event__service__pb2.GetEventsResponse.SerializeToString), 'GetEventPlacements': grpc.unary_unary_rpc_method_handler(servicer.GetEventPlacements, request_deserializer=services_dot_event__service__pb2.GetEventPlacementsRequest.FromString, response_serializer=services_dot_event__service__pb2.GetEventPlacementsResponse.SerializeToString), 'GetEventEntrants': grpc.unary_unary_rpc_method_handler(servicer.GetEventEntrants, request_deserializer=services_dot_event__service__pb2.GetEventEntrantsRequest.FromString, response_serializer=services_dot_event__service__pb2.GetEventEntrantsResponse.SerializeToString), 'ResetEvent': grpc.unary_unary_rpc_method_handler(servicer.ResetEvent, request_deserializer=services_dot_event__service__pb2.ResetEventRequest.FromString, response_serializer=services_dot_event__service__pb2.ResetEventResponse.SerializeToString), 'GetEntrantResult': grpc.unary_unary_rpc_method_handler(servicer.GetEntrantResult, request_deserializer=services_dot_event__service__pb2.GetEntrantResultRequest.FromString, response_serializer=services_dot_event__service__pb2.GetEntrantResultResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('parrygg.services.EventService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('parrygg.services.EventService', rpc_method_handlers)

class EventService(object):
    'EventService provides tournament event management operations.\n    Handles event lifecycle, registration, and bracket administration.\n    '

    @staticmethod
    def GetEvent(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.EventService/GetEvent', services_dot_event__service__pb2.GetEventRequest.SerializeToString, services_dot_event__service__pb2.GetEventResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetEvents(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.EventService/GetEvents', services_dot_event__service__pb2.GetEventsRequest.SerializeToString, services_dot_event__service__pb2.GetEventsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetEventPlacements(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.EventService/GetEventPlacements', services_dot_event__service__pb2.GetEventPlacementsRequest.SerializeToString, services_dot_event__service__pb2.GetEventPlacementsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetEventEntrants(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.EventService/GetEventEntrants', services_dot_event__service__pb2.GetEventEntrantsRequest.SerializeToString, services_dot_event__service__pb2.GetEventEntrantsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def ResetEvent(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.EventService/ResetEvent', services_dot_event__service__pb2.ResetEventRequest.SerializeToString, services_dot_event__service__pb2.ResetEventResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetEntrantResult(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.EventService/GetEntrantResult', services_dot_event__service__pb2.GetEntrantResultRequest.SerializeToString, services_dot_event__service__pb2.GetEntrantResultResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'services/page_content_service.proto')
_sym_db = _symbol_database.Default()
from ..models import tournament_pb2 as models_dot_tournament__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#services/page_content_service.proto\x12\x10parrygg.services\x1a\x17models/tournament.proto"t\n\x16GetPageContentsRequest\x12\x15\n\rtournament_id\x18\x01 \x01(\t\x12C\n\x15tournament_identifier\x18\x02 \x01(\x0b2$.parrygg.models.TournamentIdentifier"M\n\x17GetPageContentsResponse\x122\n\rpage_contents\x18\x01 \x03(\x0b2\x1b.parrygg.models.PageContent"k\n\x18CreatePageContentRequest\x12\x15\n\rtournament_id\x18\x01 \x01(\t\x128\n\x0cpage_content\x18\x02 \x01(\x0b2".parrygg.models.MutablePageContent"N\n\x19CreatePageContentResponse\x121\n\x0cpage_content\x18\x01 \x01(\x0b2\x1b.parrygg.models.PageContent"`\n\x18UpdatePageContentRequest\x12\n\n\x02id\x18\x01 \x01(\t\x128\n\x0cpage_content\x18\x02 \x01(\x0b2".parrygg.models.MutablePageContent"Z\n\x19UpdatePageContentResponse\x12\n\n\x02id\x18\x01 \x01(\t\x121\n\x0cpage_content\x18\x02 \x01(\x0b2\x1b.parrygg.models.PageContent"&\n\x18DeletePageContentRequest\x12\n\n\x02id\x18\x01 \x01(\t"N\n\x19DeletePageContentResponse\x121\n\x0cpage_content\x18\x01 \x01(\x0b2\x1b.parrygg.models.PageContent2\xce\x03\n\x12PageContentService\x12h\n\x0fGetPageContents\x12(.parrygg.services.GetPageContentsRequest\x1a).parrygg.services.GetPageContentsResponse"\x00\x12n\n\x11CreatePageContent\x12*.parrygg.services.CreatePageContentRequest\x1a+.parrygg.services.CreatePageContentResponse"\x00\x12n\n\x11UpdatePageContent\x12*.parrygg.services.UpdatePageContentRequest\x1a+.parrygg.services.UpdatePageContentResponse"\x00\x12n\n\x11DeletePageContent\x12*.parrygg.services.DeletePageContentRequest\x1a+.parrygg.services.DeletePageContentResponse"\x00B\x1a\n\x16gg.parry.grpc.servicesP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services.page_content_service_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x16gg.parry.grpc.servicesP\x01'
    _globals['_GETPAGECONTENTSREQUEST']._serialized_start = 82
    _globals['_GETPAGECONTENTSREQUEST']._serialized_end = 198
    _globals['_GETPAGECONTENTSRESPONSE']._serialized_start = 200
    _globals['_GETPAGECONTENTSRESPONSE']._serialized_end = 277
    _globals['_CREATEPAGECONTENTREQUEST']._serialized_start = 279
    _globals['_CREATEPAGECONTENTREQUEST']._serialized_end = 386
    _globals['_CREATEPAGECONTENTRESPONSE']._serialized_start = 388
    _globals['_CREATEPAGECONTENTRESPONSE']._serialized_end = 466
    _globals['_UPDATEPAGECONTENTREQUEST']._serialized_start = 468
    _globals['_UPDATEPAGECONTENTREQUEST']._serialized_end = 564
    _globals['_UPDATEPAGECONTENTRESPONSE']._serialized_start = 566
    _globals['_UPDATEPAGECONTENTRESPONSE']._serialized_end = 656
    _globals['_DELETEPAGECONTENTREQUEST']._serialized_start = 658
    _globals['_DELETEPAGECONTENTREQUEST']._serialized_end = 696
    _globals['_DELETEPAGECONTENTRESPONSE']._serialized_start = 698
    _globals['_DELETEPAGECONTENTRESPONSE']._serialized_end = 776
    _globals['_PAGECONTENTSERVICE']._serialized_start = 779
    _globals['_PAGECONTENTSERVICE']._serialized_end = 1241




'Client and server classes corresponding to protobuf-defined services.'
import grpc
import warnings
from ..services import user_service_pb2 as services_dot_user__service__pb2
GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(((((f'The grpc package installed is at version {GRPC_VERSION},' + f' but the generated code in services/user_service_pb2_grpc.py depends on') + f' grpcio>={GRPC_GENERATED_VERSION}.') + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}') + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'))

class UserServiceStub(object):
    'Missing associated documentation comment in .proto file.'

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.GetUser = channel.unary_unary('/parrygg.services.UserService/GetUser', request_serializer=services_dot_user__service__pb2.GetUserRequest.SerializeToString, response_deserializer=services_dot_user__service__pb2.GetUserResponse.FromString, _registered_method=True)
        self.GetUsers = channel.unary_unary('/parrygg.services.UserService/GetUsers', request_serializer=services_dot_user__service__pb2.GetUsersRequest.SerializeToString, response_deserializer=services_dot_user__service__pb2.GetUsersResponse.FromString, _registered_method=True)
        self.UpdateUser = channel.unary_unary('/parrygg.services.UserService/UpdateUser', request_serializer=services_dot_user__service__pb2.UpdateUserRequest.SerializeToString, response_deserializer=services_dot_user__service__pb2.UpdateUserResponse.FromString, _registered_method=True)
        self.GetUserPlacements = channel.unary_unary('/parrygg.services.UserService/GetUserPlacements', request_serializer=services_dot_user__service__pb2.GetUserPlacementsRequest.SerializeToString, response_deserializer=services_dot_user__service__pb2.GetUserPlacementsResponse.FromString, _registered_method=True)

class UserServiceServicer(object):
    'Missing associated documentation comment in .proto file.'

    def GetUser(self, request, context):
        'Retrieves a user by ID or Keycloak entity ID.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUsers(self, request, context):
        'Retrieves multiple users based on filter criteria.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUser(self, request, context):
        'Updates an existing user profile.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserPlacements(self, request, context):
        "Retrieves a user's recent placement data\n        "
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_UserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'GetUser': grpc.unary_unary_rpc_method_handler(servicer.GetUser, request_deserializer=services_dot_user__service__pb2.GetUserRequest.FromString, response_serializer=services_dot_user__service__pb2.GetUserResponse.SerializeToString), 'GetUsers': grpc.unary_unary_rpc_method_handler(servicer.GetUsers, request_deserializer=services_dot_user__service__pb2.GetUsersRequest.FromString, response_serializer=services_dot_user__service__pb2.GetUsersResponse.SerializeToString), 'UpdateUser': grpc.unary_unary_rpc_method_handler(servicer.UpdateUser, request_deserializer=services_dot_user__service__pb2.UpdateUserRequest.FromString, response_serializer=services_dot_user__service__pb2.UpdateUserResponse.SerializeToString), 'GetUserPlacements': grpc.unary_unary_rpc_method_handler(servicer.GetUserPlacements, request_deserializer=services_dot_user__service__pb2.GetUserPlacementsRequest.FromString, response_serializer=services_dot_user__service__pb2.GetUserPlacementsResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('parrygg.services.UserService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('parrygg.services.UserService', rpc_method_handlers)

class UserService(object):
    'Missing associated documentation comment in .proto file.'

    @staticmethod
    def GetUser(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.UserService/GetUser', services_dot_user__service__pb2.GetUserRequest.SerializeToString, services_dot_user__service__pb2.GetUserResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetUsers(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.UserService/GetUsers', services_dot_user__service__pb2.GetUsersRequest.SerializeToString, services_dot_user__service__pb2.GetUsersResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def UpdateUser(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.UserService/UpdateUser', services_dot_user__service__pb2.UpdateUserRequest.SerializeToString, services_dot_user__service__pb2.UpdateUserResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetUserPlacements(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.UserService/GetUserPlacements', services_dot_user__service__pb2.GetUserPlacementsRequest.SerializeToString, services_dot_user__service__pb2.GetUserPlacementsResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'services/notification_service.proto')
_sym_db = _symbol_database.Default()
from ..models import notification_pb2 as models_dot_notification__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#services/notification_service.proto\x12\x10parrygg.services\x1a\x19models/notification.proto"*\n\x17GetNotificationsRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t"O\n\x18GetNotificationsResponse\x123\n\rnotifications\x18\x01 \x03(\x0b2\x1c.parrygg.models.Notification2\x82\x01\n\x13NotificationService\x12k\n\x10GetNotifications\x12).parrygg.services.GetNotificationsRequest\x1a*.parrygg.services.GetNotificationsResponse"\x00B\x1a\n\x16gg.parry.grpc.servicesP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services.notification_service_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x16gg.parry.grpc.servicesP\x01'
    _globals['_GETNOTIFICATIONSREQUEST']._serialized_start = 84
    _globals['_GETNOTIFICATIONSREQUEST']._serialized_end = 126
    _globals['_GETNOTIFICATIONSRESPONSE']._serialized_start = 128
    _globals['_GETNOTIFICATIONSRESPONSE']._serialized_end = 207
    _globals['_NOTIFICATIONSERVICE']._serialized_start = 210
    _globals['_NOTIFICATIONSERVICE']._serialized_end = 340




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/entrant.proto')
_sym_db = _symbol_database.Default()
from ..models import request_pb2 as models_dot_request__pb2
from ..models import user_pb2 as models_dot_user__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14models/entrant.proto\x12\x0eparrygg.models\x1a\x14models/request.proto\x1a\x11models/user.proto":\n\x07Entrant\x12\n\n\x02id\x18\x01 \x01(\t\x12#\n\x05users\x18\x02 \x03(\x0b2\x14.parrygg.models.User"\xae\x01\n\x0cEventEntrant\x12\x10\n\x08event_id\x18\x01 \x01(\t\x12(\n\x07entrant\x18\x02 \x01(\x0b2\x17.parrygg.models.Entrant\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12:\n\x11teammate_requests\x18\x05 \x03(\x0b2\x1f.parrygg.models.TeammateRequest\x12\x0c\n\x04seed\x18\x06 \x01(\x05"2\n\x14EventEntrantMutation\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01B\x07\n\x05_name"<\n\x0cTeamMutation\x12\x10\n\x08user_ids\x18\x01 \x03(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01B\x07\n\x05_nameB\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.entrant_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_ENTRANT']._serialized_start = 81
    _globals['_ENTRANT']._serialized_end = 139
    _globals['_EVENTENTRANT']._serialized_start = 142
    _globals['_EVENTENTRANT']._serialized_end = 316
    _globals['_EVENTENTRANTMUTATION']._serialized_start = 318
    _globals['_EVENTENTRANTMUTATION']._serialized_end = 368
    _globals['_TEAMMUTATION']._serialized_start = 370
    _globals['_TEAMMUTATION']._serialized_end = 430




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/image.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12models/image.proto\x12\x0eparrygg.models"I\n\x05Image\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\'\n\x04type\x18\x03 \x01(\x0e2\x19.parrygg.models.ImageType*k\n\tImageType\x12\x1a\n\x16IMAGE_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11IMAGE_TYPE_BANNER\x10\x01\x12\x15\n\x11IMAGE_TYPE_AVATAR\x10\x02\x12\x14\n\x10IMAGE_TYPE_COVER\x10\x03B\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.image_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_IMAGETYPE']._serialized_start = 113
    _globals['_IMAGETYPE']._serialized_end = 220
    _globals['_IMAGE']._serialized_start = 38
    _globals['_IMAGE']._serialized_end = 111




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'models/event_export.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19models/event_export.proto\x12\x0eparrygg.models"\xc5\x01\n\x0bEventExport\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08event_id\x18\x02 \x01(\t\x121\n\x06status\x18\x03 \x01(\x0e2!.parrygg.models.EventExportStatus\x12\x14\n\x0cbraacket_url\x18\x04 \x01(\t\x12\x13\n\x0bretry_count\x18\x05 \x01(\x05\x12\x12\n\nlast_error\x18\x06 \x01(\t\x12\x12\n\ncreated_at\x18\x07 \x01(\t\x12\x12\n\nupdated_at\x18\x08 \x01(\t*\xbf\x01\n\x11EventExportStatus\x12#\n\x1fEVENT_EXPORT_STATUS_UNSPECIFIED\x10\x00\x12\x1f\n\x1bEVENT_EXPORT_STATUS_PENDING\x10\x01\x12#\n\x1fEVENT_EXPORT_STATUS_IN_PROGRESS\x10\x02\x12\x1f\n\x1bEVENT_EXPORT_STATUS_SUCCESS\x10\x03\x12\x1e\n\x1aEVENT_EXPORT_STATUS_FAILED\x10\x04B\x18\n\x14gg.parry.grpc.modelsP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.event_export_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x14gg.parry.grpc.modelsP\x01'
    _globals['_EVENTEXPORTSTATUS']._serialized_start = 246
    _globals['_EVENTEXPORTSTATUS']._serialized_end = 437
    _globals['_EVENTEXPORT']._serialized_start = 46
    _globals['_EVENTEXPORT']._serialized_end = 243




'Client and server classes corresponding to protobuf-defined services.'
import grpc
import warnings
from ..services import game_service_pb2 as services_dot_game__service__pb2
GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(((((f'The grpc package installed is at version {GRPC_VERSION},' + f' but the generated code in services/game_service_pb2_grpc.py depends on') + f' grpcio>={GRPC_GENERATED_VERSION}.') + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}') + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'))

class GameServiceStub(object):
    'GameService provides game management operations.\n    Handles game metadata, creation, and external database integration.\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.GetGames = channel.unary_unary('/parrygg.services.GameService/GetGames', request_serializer=services_dot_game__service__pb2.GetGamesRequest.SerializeToString, response_deserializer=services_dot_game__service__pb2.GetGamesResponse.FromString, _registered_method=True)
        self.GetGame = channel.unary_unary('/parrygg.services.GameService/GetGame', request_serializer=services_dot_game__service__pb2.GetGameRequest.SerializeToString, response_deserializer=services_dot_game__service__pb2.GetGameResponse.FromString, _registered_method=True)

class GameServiceServicer(object):
    'GameService provides game management operations.\n    Handles game metadata, creation, and external database integration.\n    '

    def GetGames(self, request, context):
        'List all available games for tournaments.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGame(self, request, context):
        'Retrieve a single game with all characters and stages populated.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_GameServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'GetGames': grpc.unary_unary_rpc_method_handler(servicer.GetGames, request_deserializer=services_dot_game__service__pb2.GetGamesRequest.FromString, response_serializer=services_dot_game__service__pb2.GetGamesResponse.SerializeToString), 'GetGame': grpc.unary_unary_rpc_method_handler(servicer.GetGame, request_deserializer=services_dot_game__service__pb2.GetGameRequest.FromString, response_serializer=services_dot_game__service__pb2.GetGameResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('parrygg.services.GameService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('parrygg.services.GameService', rpc_method_handlers)

class GameService(object):
    'GameService provides game management operations.\n    Handles game metadata, creation, and external database integration.\n    '

    @staticmethod
    def GetGames(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.GameService/GetGames', services_dot_game__service__pb2.GetGamesRequest.SerializeToString, services_dot_game__service__pb2.GetGamesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def GetGame(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.GameService/GetGame', services_dot_game__service__pb2.GetGameRequest.SerializeToString, services_dot_game__service__pb2.GetGameResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'services/progression_group_settings_service.proto')
_sym_db = _symbol_database.Default()
from ..models import progression_pb2 as models_dot_progression__pb2
from ..models import phase_pb2 as models_dot_phase__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1services/progression_group_settings_service.proto\x12\x10parrygg.services\x1a\x18models/progression.proto\x1a\x12models/phase.proto"0\n"GetProgressionGroupSettingsRequest\x12\n\n\x02id\x18\x01 \x01(\t"s\n#GetProgressionGroupSettingsResponse\x12L\n\x1aprogression_group_settings\x18\x01 \x01(\x0b2(.parrygg.models.ProgressionGroupSettings2\xb0\x01\n\x1fProgressionGroupSettingsService\x12\x8c\x01\n\x1bGetProgressionGroupSettings\x124.parrygg.services.GetProgressionGroupSettingsRequest\x1a5.parrygg.services.GetProgressionGroupSettingsResponse"\x00B\x1a\n\x16gg.parry.grpc.servicesP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services.progression_group_settings_service_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x16gg.parry.grpc.servicesP\x01'
    _globals['_GETPROGRESSIONGROUPSETTINGSREQUEST']._serialized_start = 117
    _globals['_GETPROGRESSIONGROUPSETTINGSREQUEST']._serialized_end = 165
    _globals['_GETPROGRESSIONGROUPSETTINGSRESPONSE']._serialized_start = 167
    _globals['_GETPROGRESSIONGROUPSETTINGSRESPONSE']._serialized_end = 282
    _globals['_PROGRESSIONGROUPSETTINGSSERVICE']._serialized_start = 285
    _globals['_PROGRESSIONGROUPSETTINGSSERVICE']._serialized_end = 461




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'services/event_service.proto')
_sym_db = _symbol_database.Default()
from ..models import event_pb2 as models_dot_event__pb2
from ..models import hierarchy_pb2 as models_dot_hierarchy__pb2
from ..models import filter_pb2 as models_dot_filter__pb2
from ..models import entrant_pb2 as models_dot_entrant__pb2
from ..models import phase_pb2 as models_dot_phase__pb2
from ..models import request_pb2 as models_dot_request__pb2
from ..models import event_export_pb2 as models_dot_event__export__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cservices/event_service.proto\x12\x10parrygg.services\x1a\x12models/event.proto\x1a\x16models/hierarchy.proto\x1a\x13models/filter.proto\x1a\x14models/entrant.proto\x1a\x12models/phase.proto\x1a\x14models/request.proto\x1a\x19models/event_export.proto"\x86\x01\n\x0fGetEventRequest\x12\n\n\x02id\x18\x01 \x01(\t\x123\n\nidentifier\x18\x02 \x01(\x0b2\x1f.parrygg.models.EventIdentifier\x122\n\x07options\x18\x03 \x01(\x0b2!.parrygg.services.GetEventOptions"8\n\x10GetEventResponse\x12$\n\x05event\x18\x01 \x01(\x0b2\x15.parrygg.models.Event"B\n\x0fGetEventOptions\x12/\n\nevent_view\x18\x01 \x01(\x0e2\x1b.parrygg.services.EventView"@\n\x10GetEventsRequest\x12,\n\x06filter\x18\x01 \x01(\x0b2\x1c.parrygg.models.EventsFilter":\n\x11GetEventsResponse\x12%\n\x06events\x18\x01 \x03(\x0b2\x15.parrygg.models.Event"\x1f\n\x11ResetEventRequest\x12\n\n\x02id\x18\x01 \x01(\t"\x14\n\x12ResetEventResponse"q\n\x19GetEventPlacementsRequest\x12\x0c\n\x02id\x18\x01 \x01(\tH\x00\x128\n\x0fevent_slug_path\x18\x02 \x01(\x0b2\x1d.parrygg.models.EventSlugPathH\x00B\x0c\n\nidentifier"K\n\x1aGetEventPlacementsResponse\x12-\n\nplacements\x18\x01 \x03(\x0b2\x19.parrygg.models.Placement"\x93\x01\n\x17GetEntrantResultRequest\x129\n\x10event_identifier\x18\x01 \x01(\x0b2\x1f.parrygg.models.EventIdentifier\x12\x14\n\nentrant_id\x18\x02 \x01(\tH\x00\x12\x11\n\x07user_id\x18\x03 \x01(\tH\x00B\x14\n\x12entrant_identifier"o\n\x18GetEntrantResultResponse\x12,\n\tplacement\x18\x01 \x01(\x0b2\x19.parrygg.models.Placement\x12%\n\x06phases\x18\x02 \x03(\x0b2\x15.parrygg.models.Phase"T\n\x17GetEventEntrantsRequest\x129\n\x10event_identifier\x18\x01 \x01(\x0b2\x1f.parrygg.models.EventIdentifier"P\n\x18GetEventEntrantsResponse\x124\n\x0eevent_entrants\x18\x01 \x03(\x0b2\x1c.parrygg.models.EventEntrant*I\n\tEventView\x12\x1c\n\x18EVENT_VIEW_SETTINGS_ONLY\x10\x00\x12\x1e\n\x1aEVENT_VIEW_BRACKET_SUMMARY\x10\x012\xe3\x04\n\x0cEventService\x12S\n\x08GetEvent\x12!.parrygg.services.GetEventRequest\x1a".parrygg.services.GetEventResponse"\x00\x12V\n\tGetEvents\x12".parrygg.services.GetEventsRequest\x1a#.parrygg.services.GetEventsResponse"\x00\x12q\n\x12GetEventPlacements\x12+.parrygg.services.GetEventPlacementsRequest\x1a,.parrygg.services.GetEventPlacementsResponse"\x00\x12k\n\x10GetEventEntrants\x12).parrygg.services.GetEventEntrantsRequest\x1a*.parrygg.services.GetEventEntrantsResponse"\x00\x12Y\n\nResetEvent\x12#.parrygg.services.ResetEventRequest\x1a$.parrygg.services.ResetEventResponse"\x00\x12k\n\x10GetEntrantResult\x12).parrygg.services.GetEntrantResultRequest\x1a*.parrygg.services.GetEntrantResultResponse"\x00B\x1a\n\x16gg.parry.grpc.servicesP\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services.event_service_pb2', _globals)
if (not _descriptor._USE_C_DESCRIPTORS):
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'\n\x16gg.parry.grpc.servicesP\x01'
    _globals['_EVENTVIEW']._serialized_start = 1273
    _globals['_EVENTVIEW']._serialized_end = 1346
    _globals['_GETEVENTREQUEST']._serialized_start = 207
    _globals['_GETEVENTREQUEST']._serialized_end = 341
    _globals['_GETEVENTRESPONSE']._serialized_start = 343
    _globals['_GETEVENTRESPONSE']._serialized_end = 399
    _globals['_GETEVENTOPTIONS']._serialized_start = 401
    _globals['_GETEVENTOPTIONS']._serialized_end = 467
    _globals['_GETEVENTSREQUEST']._serialized_start = 469
    _globals['_GETEVENTSREQUEST']._serialized_end = 533
    _globals['_GETEVENTSRESPONSE']._serialized_start = 535
    _globals['_GETEVENTSRESPONSE']._serialized_end = 593
    _globals['_RESETEVENTREQUEST']._serialized_start = 595
    _globals['_RESETEVENTREQUEST']._serialized_end = 626
    _globals['_RESETEVENTRESPONSE']._serialized_start = 628
    _globals['_RESETEVENTRESPONSE']._serialized_end = 648
    _globals['_GETEVENTPLACEMENTSREQUEST']._serialized_start = 650
    _globals['_GETEVENTPLACEMENTSREQUEST']._serialized_end = 763
    _globals['_GETEVENTPLACEMENTSRESPONSE']._serialized_start = 765
    _globals['_GETEVENTPLACEMENTSRESPONSE']._serialized_end = 840
    _globals['_GETENTRANTRESULTREQUEST']._serialized_start = 843
    _globals['_GETENTRANTRESULTREQUEST']._serialized_end = 990
    _globals['_GETENTRANTRESULTRESPONSE']._serialized_start = 992
    _globals['_GETENTRANTRESULTRESPONSE']._serialized_end = 1103
    _globals['_GETEVENTENTRANTSREQUEST']._serialized_start = 1105
    _globals['_GETEVENTENTRANTSREQUEST']._serialized_end = 1189
    _globals['_GETEVENTENTRANTSRESPONSE']._serialized_start = 1191
    _globals['_GETEVENTENTRANTSRESPONSE']._serialized_end = 1271
    _globals['_EVENTSERVICE']._serialized_start = 1349
    _globals['_EVENTSERVICE']._serialized_end = 1960




'Client and server classes corresponding to protobuf-defined services.'
import grpc
import warnings
from ..services import match_game_service_pb2 as services_dot_match__game__service__pb2
GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(((((f'The grpc package installed is at version {GRPC_VERSION},' + f' but the generated code in services/match_game_service_pb2_grpc.py depends on') + f' grpcio>={GRPC_GENERATED_VERSION}.') + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}') + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'))

class MatchGameServiceStub(object):
    'MatchGameService provides match game management operations.\n    Handles individual games within matches including stage selection and per-game scoring.\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.CreateMatchGame = channel.unary_unary('/parrygg.services.MatchGameService/CreateMatchGame', request_serializer=services_dot_match__game__service__pb2.CreateMatchGameRequest.SerializeToString, response_deserializer=services_dot_match__game__service__pb2.CreateMatchGameResponse.FromString, _registered_method=True)
        self.UpdateMatchGame = channel.unary_unary('/parrygg.services.MatchGameService/UpdateMatchGame', request_serializer=services_dot_match__game__service__pb2.UpdateMatchGameRequest.SerializeToString, response_deserializer=services_dot_match__game__service__pb2.UpdateMatchGameResponse.FromString, _registered_method=True)
        self.DeleteMatchGame = channel.unary_unary('/parrygg.services.MatchGameService/DeleteMatchGame', request_serializer=services_dot_match__game__service__pb2.DeleteMatchGameRequest.SerializeToString, response_deserializer=services_dot_match__game__service__pb2.DeleteMatchGameResponse.FromString, _registered_method=True)

class MatchGameServiceServicer(object):
    'MatchGameService provides match game management operations.\n    Handles individual games within matches including stage selection and per-game scoring.\n    '

    def CreateMatchGame(self, request, context):
        'Create a new game within a match.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMatchGame(self, request, context):
        "Update an existing match game's data.\n        "
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMatchGame(self, request, context):
        'Delete a match game from its parent match.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_MatchGameServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'CreateMatchGame': grpc.unary_unary_rpc_method_handler(servicer.CreateMatchGame, request_deserializer=services_dot_match__game__service__pb2.CreateMatchGameRequest.FromString, response_serializer=services_dot_match__game__service__pb2.CreateMatchGameResponse.SerializeToString), 'UpdateMatchGame': grpc.unary_unary_rpc_method_handler(servicer.UpdateMatchGame, request_deserializer=services_dot_match__game__service__pb2.UpdateMatchGameRequest.FromString, response_serializer=services_dot_match__game__service__pb2.UpdateMatchGameResponse.SerializeToString), 'DeleteMatchGame': grpc.unary_unary_rpc_method_handler(servicer.DeleteMatchGame, request_deserializer=services_dot_match__game__service__pb2.DeleteMatchGameRequest.FromString, response_serializer=services_dot_match__game__service__pb2.DeleteMatchGameResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('parrygg.services.MatchGameService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('parrygg.services.MatchGameService', rpc_method_handlers)

class MatchGameService(object):
    'MatchGameService provides match game management operations.\n    Handles individual games within matches including stage selection and per-game scoring.\n    '

    @staticmethod
    def CreateMatchGame(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.MatchGameService/CreateMatchGame', services_dot_match__game__service__pb2.CreateMatchGameRequest.SerializeToString, services_dot_match__game__service__pb2.CreateMatchGameResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def UpdateMatchGame(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.MatchGameService/UpdateMatchGame', services_dot_match__game__service__pb2.UpdateMatchGameRequest.SerializeToString, services_dot_match__game__service__pb2.UpdateMatchGameResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def DeleteMatchGame(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/parrygg.services.MatchGameService/DeleteMatchGame', services_dot_match__game__service__pb2.DeleteMatchGameRequest.SerializeToString, services_dot_match__game__service__pb2.DeleteMatchGameResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)
